==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/GetEvaluationsOfInteraction.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationsOfInteraction] (
	@Instance Varchar(50) = NULL,
	@IdInteraction VARCHAR(MAX) = NULL,
	@InteractionType VARCHAR(MAX) = NULL,
	@EvaluationDateFrom VARCHAR(MAX) = '1980-01-01',
	@EvaluationDateTo VARCHAR(MAX) = '2050-01-01'
	)
AS
BEGIN
	SET NOCOUNT ON;

	-- CREAMOS UNA CTE PARA AGRUPAR LOS RESULTADOS DE CADA INTERACCION POR PLAN
	WITH ER_CTE AS (
		SELECT ER.[Instance]															'vcc',
				ER.[IdEvaluationPlan]													'idEvaluationPlan',
				ER.[InteractionType]													'interactionType',
				ER.[IdInteraction]														'idInteraction',
				SUM(ISNULL(TRY_CAST(ER.[ScoreDescription] AS DECIMAL(18, 2)), 0))		'scoreDescription',
				--SUM(ER.[ScoreDescription])				'scoreDescription',
				ER.[IdEvaluator]														'idEvaluator',
				MAX(ER.[EvaluationDate])												'evaluationDate'
			FROM [dbo].[EvaluationResult] ER (NOLOCK)
			WHERE ER.[Instance] = @Instance
				AND ER.[IdInteraction] = @IdInteraction
				AND ER.[InteractionType] = @InteractionType
				AND ER.[EvaluationDate] BETWEEN @EvaluationDateFrom AND @EvaluationDateTo
			GROUP BY ER.[Instance], ER.[IdEvaluationPlan], ER.[InteractionType], ER.[IdInteraction], ER.[IdEvaluator]
	) 

	SELECT AEP.[Completed]									'completed',
			AEP.[score]										'score',
			AEP.[IdAuditor]									'idAuditor',
			U.[FirstName] + ' ' + U.[LastName]				'auditorName',
			ER.[EvaluationDate]					            'evaluationDate',
			EP.[ID]											'idEvaluationPlan',
			EP.[Description]								'evaluationPlan',
			AEP.[idAgent]									'idAgent',
			AEP.[IdInteraction]								'idInteraction',
			AEP.[InteractionType]							'interactionType'
		FROM ER_CTE ER (NOLOCK)
		INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
			ON EP.[Instance] = ER.[vcc]
				AND EP.[ID] = ER.[idEvaluationPlan]
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			ON AEP.[Instance] = ER.[vcc]
				AND AEP.[IdEvaluationPlan] = ER.[idEvaluationPlan]
				AND AEP.[IdInteraction] = ER.[idInteraction]
				AND AEP.[IdAuditor] = ER.[idEvaluator]
				AND AEP.[InteractionType] = ER.[interactionType]
		INNER JOIN [dbo].[User] U (NOLOCK)
			ON U.[VCC] = EP.[Instance]
				AND U.[ID] = AEP.[IdAuditor]
		ORDER BY ER.[evaluationDate] DESC

	/*

	SELECT * 
		FROM [dbo].[EvaluationPlan] EP (NOLOCK) 
		LEFT JOIN [dbo].[EvaluationResult] ER (NOLOCK)
			ON ER.[Instance] = EP.[Instance]
				AND ER.[IdEvaluationPlan] = EP.[ID]
		LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			ON AEP.[Instance] = EP.[Instance]
				AND AEP.[IdEvaluationPlan] = EP.[ID]


				

	SELECT
		p.Completed						'completed',
		p.score							'score',
		p.IdAuditor						'idAuditor',
		a.FirstName + ' ' + a.LastName	'auditorName',
		MAX(e.EvaluationDate)             'evaluationDate',
		p.IdEvaluationPlan				'idEvaluationPlan',
		ep.Description					'evaluationPlan',
		p.idAgent						'idAgent',
		p.idInteraction					'idInteraction',
		p.InteractionType				'interactionType'
	FROM [EvaluationPlan] ep, EvaluationResult e, AuditorEvaluationPlan p, [User] a (NOLOCK)
	WHERE
	p.Instance = @Instance
	AND p.IdInteraction = @IdInteraction
	AND p.instance = e.instance
	AND p.IdInteraction = e.IdInteraction
	AND p.IdEvaluationPlan = e.IdEvaluationPlan
	AND p.IdAuditor = e.IdEvaluator
	AND p.InteractionType = e.InteractionType
	AND e.EvaluationDate >= @EvaluationDateFrom
	AND e.EvaluationDate <= @EvaluationDateTo
	AND a.ID = p.IdAuditor
	AND a.[VCC] = EP.[Instance]
	AND p.InteractionType = @InteractionType
	AND ep.Instance = e.instance
	AND ep.ID = p.IdEvaluationPlan
	GROUP BY p.Completed, 
				p.score, 
				p.IdAuditor, 
				a.FirstName + ' ' + a.LastName, 
				e.EvaluationDate, 
				p.IdEvaluationPlan, 
				ep.Description, 
				p.idAgent, 
				p.idInteraction, 
				p.InteractionType
	ORDER BY e.EvaluationDate DESC
	*/
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/GetEvaluationsOfInteraction.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationsOfInteraction] (
	@Instance Varchar(50) = NULL,
	@IdInteraction VARCHAR(MAX) = NULL,
	@InteractionType VARCHAR(MAX) = NULL,
	@EvaluationDateFrom VARCHAR(MAX) = '1980-01-01',
	@EvaluationDateTo VARCHAR(MAX) = '2050-01-01'
	)
AS
BEGIN
	SET NOCOUNT ON;
	
	-- CREAMOS UNA CTE PARA AGRUPAR LOS RESULTADOS DE CADA INTERACCION POR PLAN
	WITH ER_CTE AS (
		SELECT ER.[Instance]															'vcc',
				ER.[IdEvaluationPlan]													'idEvaluationPlan',
				ER.[InteractionType]													'interactionType',
				ER.[IdInteraction]														'idInteraction',
				SUM(ISNULL(TRY_CAST(ER.[ScoreDescription] AS DECIMAL(18, 2)), 0))		'scoreDescription',
				--SUM(ER.[ScoreDescription])				'scoreDescription',
				--ER.[IdEvaluator]														'idEvaluator', <= DESDE PLANES MIXTOS YA NO SE PUEDE AGRUPAR EN BASE A ESTA COLUMNA
				ER.[IdAuditor]															'idAuditor',
				MAX(ER.[EvaluationDate])												'evaluationDate'
			FROM [dbo].[EvaluationResult] ER (NOLOCK)
			WHERE ER.[Instance] = @Instance
				AND ER.[IdInteraction] = @IdInteraction
				AND ER.[InteractionType] = @InteractionType
				AND ER.[EvaluationDate] BETWEEN @EvaluationDateFrom AND @EvaluationDateTo
			GROUP BY ER.[Instance], ER.[IdEvaluationPlan], ER.[InteractionType], ER.[IdInteraction], ER.[idAuditor]
	) 

	SELECT AEP.[Completed]									'completed',
			AEP.[score]										'score',
			AEP.[IdAuditor]									'idAuditor',
			U.[FirstName] + ' ' + U.[LastName]				'auditorName',
			ER.[EvaluationDate]					            'evaluationDate',
			EP.[ID]											'idEvaluationPlan',
			EP.[Description]								'evaluationPlan',
			AEP.[idAgent]									'idAgent',
			AEP.[IdInteraction]								'idInteraction',
			AEP.[InteractionType]							'interactionType'
		FROM ER_CTE ER (NOLOCK)
		INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
			ON EP.[Instance] = ER.[vcc]
				AND EP.[ID] = ER.[idEvaluationPlan]
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			ON AEP.[Instance] = ER.[vcc]
				AND AEP.[IdEvaluationPlan] = ER.[idEvaluationPlan]
				AND AEP.[IdInteraction] = ER.[idInteraction]
				AND AEP.[IdAuditor] = ER.[idAuditor]
				AND AEP.[InteractionType] = ER.[interactionType]
		LEFT JOIN [dbo].[User] U (NOLOCK) -- QUEDA COMO LEFT JOIN EN CASO NO ENCUENTRE EL AUDITOR AUN SERA VISIBLE EL RESULTADO
			ON U.[VCC] = EP.[Instance]
				AND U.[ID] = AEP.[IdAuditor]
		ORDER BY ER.[evaluationDate] DESC

	/*

	SELECT * 
		FROM [dbo].[EvaluationPlan] EP (NOLOCK) 
		LEFT JOIN [dbo].[EvaluationResult] ER (NOLOCK)
			ON ER.[Instance] = EP.[Instance]
				AND ER.[IdEvaluationPlan] = EP.[ID]
		LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			ON AEP.[Instance] = EP.[Instance]
				AND AEP.[IdEvaluationPlan] = EP.[ID]


				

	SELECT
		p.Completed						'completed',
		p.score							'score',
		p.IdAuditor						'idAuditor',
		a.FirstName + ' ' + a.LastName	'auditorName',
		MAX(e.EvaluationDate)             'evaluationDate',
		p.IdEvaluationPlan				'idEvaluationPlan',
		ep.Description					'evaluationPlan',
		p.idAgent						'idAgent',
		p.idInteraction					'idInteraction',
		p.InteractionType				'interactionType'
	FROM [EvaluationPlan] ep, EvaluationResult e, AuditorEvaluationPlan p, [User] a (NOLOCK)
	WHERE
	p.Instance = @Instance
	AND p.IdInteraction = @IdInteraction
	AND p.instance = e.instance
	AND p.IdInteraction = e.IdInteraction
	AND p.IdEvaluationPlan = e.IdEvaluationPlan
	AND p.IdAuditor = e.IdEvaluator
	AND p.InteractionType = e.InteractionType
	AND e.EvaluationDate >= @EvaluationDateFrom
	AND e.EvaluationDate <= @EvaluationDateTo
	AND a.ID = p.IdAuditor
	AND a.[VCC] = EP.[Instance]
	AND p.InteractionType = @InteractionType
	AND ep.Instance = e.instance
	AND ep.ID = p.IdEvaluationPlan
	GROUP BY p.Completed, 
				p.score, 
				p.IdAuditor, 
				a.FirstName + ' ' + a.LastName, 
				e.EvaluationDate, 
				p.IdEvaluationPlan, 
				ep.Description, 
				p.idAgent, 
				p.idInteraction, 
				p.InteractionType
	ORDER BY e.EvaluationDate DESC
	*/
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
